<?php

/**
 * @file
 * Functions to deal with url signing
 */

/**
 * Return a URL safe base64 encoded string (RFC 3458 Section 4).
 */
function mediacorechooser_urlsafe_b64encode($value) {
  $encoded_value = base64_encode($value);
  $encoded_value = strtr($encoded_value, '+/', '-_');
  $encoded_value = trim($encoded_value, '=');
  return $encoded_value;
}

/**
 * Generate a signature for the given key and value.
 */
function mediacorechooser_get_signature($secret_key, $value) {
  $secret_key = base64_decode($secret_key);

  if (strlen($secret_key) == 128) {
    $mac = hash_hmac("sha512", $value, $secret_key, TRUE);
  }
  else {
    $mac = hash_hmac("sha256", $value, $secret_key, TRUE);
  }

  return $mac;
}

/**
 * Create a signature for the given MediaCore URL.
 */
function mediacorechooser_get_signed_qs($url, $query_string, $key_id, $secret_key, $ttl = NULL, $expiry_epoch = NULL, $ip_mask = NULL) {
  if ($expiry_epoch === NULL and $ttl !== NULL) {
    $expiry_epoch = time() + $ttl;
  }

  $policy = array();
  $policy['resource'] = $url;
  if ($query_string != '') {
    $policy['query_string'] = $query_string;
  }
  if ($ip_mask !== NULL) {
    $policy['ip_range'] = $ip_mask;
  }
  if ($expiry_epoch !== NULL) {
    $policy['expiry_epoch'] = $expiry_epoch;
  }

  $policy_string = json_encode($policy);
  $encoded_policy_string = mediacorechooser_urlsafe_b64encode($policy_string);

  $signature = mediacorechooser_get_signature($secret_key, $encoded_policy_string);
  $encoded_signature = mediacorechooser_urlsafe_b64encode($signature);

  $policy_qs = '_Policy=%s&_Signature=%s&_KeyId=%s';
  $new_qs = sprintf($policy_qs, $encoded_policy_string, $encoded_signature, $key_id);

  if (!in_array($query_string, array('', '*'))) {
    $new_qs = $query_string . '&' . $new_qs;
  }
  return $new_qs;
}
